@@ -33,11 +33,11 @@ class RedditExtractor(Extractor):
         previews = self.config("previews", True)
         embeds = self.config("embeds", True)
 
-        if videos := self.config("videos", True):
-            if videos == "ytdl":
-                self._extract_video = self._extract_video_ytdl
-            elif videos == "dash":
+        if videos := self.config("videos", "dash"):
+            if videos == "dash":
                 self._extract_video = self._extract_video_dash
+            elif videos == "ytdl":
+                self._extract_video = self._extract_video_ytdl
             videos = True
 
         selftext = self.config("selftext")
@@ -55,7 +55,7 @@ class RedditExtractor(Extractor):
             for submission, comments in submissions:
                 urls = []
 
-                if submission:
+                if submission and submission.get("_media", True):
                     submission["comment"] = None
                     submission["date"] = self.parse_timestamp(
                         submission["created_utc"])
@@ -126,7 +126,7 @@ class RedditExtractor(Extractor):
 
                         data = submission.copy()
                         data["comment"] = comment
-                        comment["date"] = self.parse_timestamp(
+                        comment["date"] = data["date"] = self.parse_timestamp(
                             comment["created_utc"])
 
                         if media:
@@ -215,7 +215,10 @@ class RedditExtractor(Extractor):
 
             if src := data.get("s"):
                 if url := src.get("u") or src.get("gif") or src.get("mp4"):
-                    yield url.partition("?")[0].replace("/preview.", "/i.", 1)
+                    if "//external" not in url:
+                        url = url.partition("?")[0].replace(
+                            "/preview.", "/i.", 1)
+                    yield url
                 else:
                     self.log.error(
                         "embed %s: unable to fetch download URL for item %s",
@@ -223,10 +226,10 @@ class RedditExtractor(Extractor):
                     self.log.debug(src)
             elif url := data.get("dashUrl"):
                 submission["_ytdl_manifest"] = "dash"
-                yield f"ytdl:{url}"
+                yield "ytdl:" + url
             elif url := data.get("hlsUrl"):
                 submission["_ytdl_manifest"] = "hls"
-                yield f"ytdl:{url}"
+                yield "ytdl:" + url
 
     def _extract_video_ytdl(self, submission):
         return "https://www.reddit.com" + submission["permalink"]
@@ -300,19 +303,39 @@ class RedditHomeExtractor(RedditSubredditExtractor):
 class RedditUserExtractor(RedditExtractor):
     """Extractor for URLs from posts by a reddit user"""
     subcategory = "user"
+    directory_fmt = ("{category}", "Users", "{user[name]}")
     pattern = (r"(?:https?://)?(?:\w+\.)?reddit\.com/u(?:ser)?/"
-               r"([^/?#]+(?:/([a-z]+))?)/?(?:\?([^#]*))?$")
+               r"([^/?#]+)(/[a-z]+)?/?(?:\?([^#]*))?")
     example = "https://www.reddit.com/user/USER/"
 
     def __init__(self, match):
-        self.user, sub, params = match.groups()
-        self.params = text.parse_query(params)
-        if sub:
-            self.subcategory += "-" + sub
+        if sub := match[2]:
+            self.subcategory += "-" + sub[1:]
         RedditExtractor.__init__(self, match)
 
     def submissions(self):
-        return self.api.submissions_user(self.user, self.params)
+        username, sub, qs = self.groups
+        username = text.unquote(username)
+        self.kwdict["user"] = user = self.api.user_about(username)
+
+        submissions = self.api.submissions_user(
+            (user.get("name") or username) + (sub or ""), text.parse_query(qs))
+        if self.config("only", sub != "/saved"):
+            submissions = self._only(submissions, user)
+        return submissions
+
+    def _only(self, submissions, user):
+        uid = "t2_" + user["id"]
+        for submission, comments in submissions:
+            if submission and submission.get("author_fullname") != uid:
+                submission["_media"] = False
+            comments = [
+                comment
+                for comment in (comments or ())
+                if comment.get("author_fullname") == uid
+            ]
+            if submission or comments:
+                yield submission, comments
 
 
 class RedditSubmissionExtractor(RedditExtractor):
@@ -323,12 +346,8 @@ class RedditSubmissionExtractor(RedditExtractor):
                r"comments|gallery)|redd\.it)/([a-z0-9]+)")
     example = "https://www.reddit.com/r/SUBREDDIT/comments/id/"
 
-    def __init__(self, match):
-        RedditExtractor.__init__(self, match)
-        self.submission_id = match[1]
-
     def submissions(self):
-        return (self.api.submission(self.submission_id),)
+        return (self.api.submission(self.groups[0]),)
 
 
 class RedditImageExtractor(Extractor):
@@ -449,9 +468,9 @@ class RedditAPI():
         endpoint = subreddit + "/.json"
         return self._pagination(endpoint, params)
 
-    def submissions_user(self, user, params):
+    def submissions_user(self, username, params):
         """Collect all (submission, comments)-tuples posted by a user"""
-        endpoint = "/user/" + user + "/.json"
+        endpoint = f"/user/{username}/.json"
         return self._pagination(endpoint, params)
 
     def morechildren(self, link_id, children):
@@ -468,10 +487,15 @@ class RedditAPI():
             data = self._call(endpoint, params)["json"]
             for thing in data["data"]["things"]:
                 if thing["kind"] == "more":
-                    children.extend(thing["data"]["children"])
+                    if more := thing["data"].get("children"):
+                        children.extend(more)
                 else:
                     yield thing["data"]
 
+    def user_about(self, username):
+        endpoint = f"/user/{username}/about.json"
+        return self._call(endpoint, {})["data"]
+
     def authenticate(self):
         """Authenticate the application by requesting an access token"""
         self.headers["Authorization"] = \
@@ -506,7 +530,7 @@ class RedditAPI():
         return "Bearer " + data["access_token"]
 
     def _call(self, endpoint, params):
-        url = f"{self.root}{endpoint}"
+        url = self.root + endpoint
         params["raw_json"] = "1"
 
         while True:
