@@ -528,6 +528,11 @@ def build_parser():
               "This can be either a constant value or a range "
               "(e.g. 2.7 or 2.0-3.5)"),
     )
+    downloader.add_argument(
+        "--sleep-skip",
+        dest="sleep-skip", metavar="SECONDS", action=ConfigAction,
+        help=("Number of seconds to wait after skipping a file download"),
+    )
     downloader.add_argument(
         "--sleep-request",
         dest="sleep-request", metavar="SECONDS", action=ConfigAction,
@@ -843,7 +848,8 @@ def build_parser():
         action=AppendCommandAction, const={"name": "exec"},
         help=("Execute CMD for each downloaded file. "
               "Supported replacement fields are "
-              "{} or {_path}, {_directory}, {_filename}. "
+              "{} or {_path}, {_temppath}, {_directory}, {_filename}. "
+              "On Windows, use {_path_unc} or {_directory_unc} for UNC paths. "
               "Example: --exec \"convert {} {}.png && rm {}\""),
     )
     postprocessor.add_argument(
