@@ -89,6 +89,7 @@ __tests__ = (
         "mimetype"      : "video/mp4",
         "originalHeight": 590,
         "originalWidth" : 786,
+        "preview"       : False,
         "resolutionMode": 1,
         "status"        : 1,
         "type"          : "video",
@@ -98,6 +99,40 @@ __tests__ = (
     },
 },
 
+{
+    "#url"     : "https://fansly.com/post/527804734266941440",
+    "#comment" : "preview image (#8686)",
+    "#class"   : fansly.FanslyPostExtractor,
+    "#auth"    : "token",
+    "#pattern" : r"https://cdn3.fansly.com/509388488890658816/527804380229935104.jpeg\?ngsw-bypass=true&Expires=\d+.+",
+
+    "createdAt"      : 1687332814,
+    "date"           : "dt:2023-06-21 07:33:34",
+    "extension"      : "jpeg",
+    "filename"       : "527804380229935104",
+    "fypFlags"       : 2,
+    "id"             : "527804734266941440",
+    "file"           : {
+        "accountId"     : "509388488890658816",
+        "createdAt"     : 1687332730,
+        "date"          : "dt:2023-06-21 07:32:10",
+        "date_updated"  : "dt:2023-06-21 07:32:13",
+        "flags"         : 394,
+        "format"        : 1,
+        "height"        : 1464,
+        "id"            : "527804380229935104",
+        "location"      : "/509388488890658816/527804380229935104.jpeg",
+        "mimetype"      : "image/jpeg",
+        "preview"       : True,
+        "resolutionMode": 2,
+        "status"        : 1,
+        "type"          : "image",
+        "updatedAt"     : 1687332733,
+        "variantHash"   : {},
+        "width"         : 1349,
+    },
+},
+
 {
     "#url"     : "https://fansly.com/Oliviaus/posts",
     "#class"   : fansly.FanslyCreatorPostsExtractor,
