@@ -13,12 +13,12 @@ __tests__ = (
     "#class"   : fikfap.FikfapPostExtractor,
     "#pattern" : r"ytdl:https://vz-\w+-178\.b-cdn\.net/bcdn_token=.+/playlist\.m3u8",
 
-    "algorithm"      : "user-posts",
+    "algorithm"      : "single-post",
     "bunnyVideoId"   : "89218ae2-d79a-49a0-abcd-590fd70c9800",
     "commentsCount"  : int,
     "createdAt"      : "2025-10-21T00:49:00.306Z",
     "date"           : "dt:2025-10-21 00:49:00",
-    "date_updated"   : "dt:2026-02-07 01:07:45",
+    "date_updated"   : "type:datetime",
     "deletedAt"      : None,
     "duration"       : None,
     "explicitnessRating": None,
@@ -99,6 +99,25 @@ __tests__ = (
     },
 },
 
+{
+    "#url"     : "https://fikfap.com/post/1429486",
+    "#class"   : fikfap.FikfapPostExtractor,
+    "#pattern" : r"ytdl:https://vz-\w+-178\.b-cdn\.net/bcdn_token=.+/playlist\.m3u8",
+
+    "bunnyVideoId": "89218ae2-d79a-49a0-abcd-590fd70c9800",
+    "date"        : "dt:2025-10-21 00:49:00",
+    "extension"   : "mp4",
+    "filename"    : "⬇️check my FREE VIP OF ⬇️",
+    "mediaId"     : "b821619e-96a1-49a3-a3f8-a8a3e8432a51",
+    "postId"      : 1429486,
+    "userId"      : "32f4c8d6-2409-4db8-9e66-d3b5ff0c1a98",
+},
+
+{
+    "#url"     : "https://fikfap.com/user/Hot-sauce-34/post/1026309",
+    "#class"   : fikfap.FikfapPostExtractor,
+},
+
 {
     "#url"     : "https://fikfap.com/user/alinevs",
     "#class"   : fikfap.FikfapUserExtractor,
@@ -135,4 +154,9 @@ __tests__ = (
     "hashtag"  : "outercourse",
 },
 
+{
+    "#url"     : "https://fikfap.com/hash/foo-bar",
+    "#class"   : fikfap.FikfapHashtagExtractor,
+},
+
 )
