@@ -91,6 +91,25 @@ __tests__ = (
     "#class"   : reddit.RedditUserExtractor,
 },
 
+{
+    "#url"     : "https://www.reddit.com/user/SeichiScout/submitted/?sort=hot",
+    "#category": ("", "reddit", "user-submitted"),
+    "#class"   : reddit.RedditUserExtractor,
+    "#pattern" : r"https://i\.redd\.it/\w+\.jpg",
+    "#range"   : "1-25",
+    "#count"   : 25,
+    "#archive" : False,
+
+    "author"          : "SeichiScout",
+    "author_fullname" : "t2_l8qpy6td6",
+    "user"            : {
+        "created_utc" : 1724480738.0,
+        "id"          : "l8qpy6td6",
+        "name"        : "SeichiScout",
+        "verified"    : True,
+    },
+},
+
 {
     "#url"     : "https://www.reddit.com/r/lavaporn/comments/8cqhub/",
     "#category": ("", "reddit", "submission"),
@@ -284,6 +303,16 @@ __tests__ = (
     "#results" : "ytdl:https://v.redd.it/link/1n260wh/asset/8q50b220tplf1/DASHPlaylist.mpd?a=1759085227%2CYTU2NGJjNTlmNjBlOGE2NWUwYWI0MjRjZDYzZjllZjk4Nzc3Y2Y4Nzc1NDMzOTBkYTNkOWFjOGMzZjUzZDAzMQ%3D%3D&v=1&f=sd",
 },
 
+{
+    "#url"     : "https://www.reddit.com/r/vi/comments/1qi6tev/comment/o0v9zh8/",
+    "#comment" : "'external-preview' embed",
+    "#class"   : reddit.RedditSubmissionExtractor,
+    "#options" : {"comments": 100},
+    "#range"   : "2",
+    "#pattern" : r"https://external-preview.redd.it/0DT-wjorv2NNSSoTW-62QG4xs7ZqGE2jcn2OEa2Xnks\.gif\?width=200&height=200&s=\w+",
+    "#sha1_content": "5014a016d7d5fb2c9fdaa01f0b43afeff158cd9b",
+},
+
 {
     "#url"     : "https://i.redd.it/upjtjcx2npzz.jpg",
     "#category": ("", "reddit", "image"),
