@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright 2021-2025 Mike Fährmann
+# Copyright 2021-2026 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -158,6 +158,15 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{ds:D%Y-%m-%dT%H:%M:%S%z}", self.kwdict["dt"],
                        None, util.identity)
 
+    def test_fmt_func_multi(self):
+        self._run_test("foo {t}" , f"foo {self.kwdict['t']}",
+                       None, int)
+        self._run_test("bar {ds}", f"bar {self.kwdict['dt']}",
+                       None, dt.parse_iso)
+        self._run_test("foo {ds:D%Y-%m-%dT%H:%M:%S%z} bar",
+                       f"foo {self.kwdict['dt']} bar",
+                       None, util.identity)
+
     def test_alternative(self):
         self._run_test("{a|z}"    , "hElLo wOrLd")
         self._run_test("{z|a}"    , "hElLo wOrLd")
@@ -188,6 +197,27 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{d['a']}", "foo")
         self._run_test('{d["a"]}', "foo")
 
+    def test_dot_index(self):
+        self._run_test("{l.1}"  , "b")
+        self._run_test("{a.6}"  , "w")
+        self._run_test("{a.99}" , "None")
+        self._run_test("{l.-1}" , "c")
+        self._run_test("{a.-7}" , "o")
+        self._run_test("{a.-0}" , "h")  # same as a[0]
+        self._run_test("{a.-99}", "None")
+
+    def test_dot_access_dict(self):
+        self._run_test("{d.a}", "foo")
+        self._run_test("{d.d}", "None")
+        self._run_test("{a.d}", "None")
+        self._run_test("{L.0.age}", "42")
+        self._run_test("{L.-1.name.2}", "x")
+        self._run_test("{L.1:I}", self.kwdict["L"][1])
+
+    def test_dot_access_attr(self):
+        self._run_test("{t.real}", "1262304000")
+        self._run_test("{dt.year}", "2010")
+
     def test_slice_str(self):
         v = self.kwdict["a"]
         self._run_test("{a[1:10]}"  , v[1:10])
@@ -369,6 +399,15 @@ class TestFormatter(unittest.TestCase):
         with self.assertRaises(ValueError):
             self._run_test("{t:Mname", "")
 
+    def test_specifier_identity(self):
+        self._run_test("{a:I}", self.kwdict["a"])
+        self._run_test("{i:I}", self.kwdict["i"])
+        self._run_test("{dt:I}", self.kwdict["dt"])
+
+        self._run_test("{t!D:I}", self.kwdict["dt"])
+        self._run_test("{t!D:I/O+01:30}", self.kwdict["dt"])
+        self._run_test("{i:A+1/I}", self.kwdict["i"]+1)
+
     def test_chain_special(self):
         # multiple replacements
         self._run_test("{a:Rh/C/RE/e/RL/l/}", "Cello wOrld")
